@@ -3,13 +3,10 @@ use strict;
 use warnings;
 use parent qw/Skype::Any::Object/;
 
-sub property { shift->_property('SMS', @_) }
-sub alter    { shift->_alter('SMS', @_) }
+sub property { shift->SUPER::property('SMS', @_) }
+sub alter    { shift->SUPER::alter('SMS', @_) }
 
-for my $property (qw/is_failed_unseen/) {
-    no strict 'refs';
-    *{$property} = sub { $_[0]->_boolean($property) };
-}
+__PACKAGE__->_mk_bool_property(qw/is_failed_unseen/);
 
 1;
 __END__
@@ -20,14 +17,16 @@ Skype::Any::Object::SMS - SMS object for Skype::Any
 
 =head1 SYNOPSIS
 
-    use Skype::Any;
+  use Skype::Any;
 
-    my $skype = Skype::Any->new;
-    my $sms = $skype->sms($id);
+  my $skype = Skype::Any->new;
+  my $sms = $skype->sms($id);
 
 =head1 METHODS
 
-=head2 C<property>
+=over 4
+
+=item C<< $sms->property($property[, $value]) >>
 
 =over 4
 
@@ -57,8 +56,8 @@ Skype::Any::Object::SMS - SMS object for Skype::Any
 
 =back
 
-=head1 SEE ALSO
+=item C<< $sms->alter($action[, $value]) >>
 
-L<Skype::Any::Object>
+=back
 
 =cut
